@@ -67,7 +67,6 @@ static int print_persistent_state(char *qspi_mtd_file);
 static int print_qspi_mfg_info(void);
 static void print_usage(void);
 static int print_image_rev_info(char *qspi_mtd_file, char *image_name);
-static int clear_multiboot_val(void);
 
 /* Variable definitions */
 static char *srcaddr = NULL;
@@ -164,7 +163,6 @@ int main(int argc, char *argv[])
 	int ret = XST_FAILURE;
 	char qspi_mtd_file[20U] = {0U};
 	char image_file_name[100U] = {0U};
-	char image_name[8] = {0U};
 	int opt;
 	int update_flag = 0;
 	int verify_flag = 0;
@@ -271,7 +269,7 @@ int main(int argc, char *argv[])
 		return ret;
 	}
 
-	printf("Reading Image file\n");
+	printf("Reading Image..\n");
 	ret = read_image_file(image_file_name);
 	if (ret != XST_SUCCESS)
 		goto END;
@@ -281,18 +279,14 @@ int main(int argc, char *argv[])
 	 */
 	if (boot_img_info.persistent_state.last_booted_img ==
 		(char)SYS_BOOT_IMG_A_ID) {
-		printf("Updating Image B\n");
-		strcpy(image_name, "Image B");
 		boot_img_info.persistent_state.img_b_bootable = 0U;
 		strcpy(qspi_mtd_file, "/dev/mtd7");
 	} else {
-		printf("Updating Image A\n");
-		strcpy(image_name, "Image A");
 		boot_img_info.persistent_state.img_a_bootable = 0U;
 		strcpy(qspi_mtd_file, "/dev/mtd5");
 	}
 
-	printf("Marking target image as non bootable\n");
+	printf("Marking target image non bootable\n");
 	ret = update_persistent_registers("/dev/mtd2");
 	if (ret < 0)
 		goto END;
@@ -301,7 +295,7 @@ int main(int argc, char *argv[])
 	if (ret < 0)
 		goto END;
 
-	printf("Writing Image to %s partition\n",image_name);
+	printf("Writing Image..\n");
 	ret = update_image(qspi_mtd_file);
 	if (ret != XST_SUCCESS)
 		goto END;
@@ -325,12 +319,7 @@ int main(int argc, char *argv[])
 	if (ret < 0)
 		goto END;
 
-	printf("Clearing multiboot register value\n");
-	ret = clear_multiboot_val();
-	if (ret != XST_SUCCESS)
-		goto END;
-
-	printf("%s successfully updated to %s partition\n", image_file_name, image_name);
+	printf("%s updated successfully\n", image_file_name);
 
 END:
 	if (srcaddr)
@@ -871,26 +860,6 @@ END:
 	return ret;
 }
 
-/*****************************************************************************/
-/**
- * @brief
- * This function clears multiboot register value.
- *
- * @return	XST_SUCCESS on success and XST_FAILURE on failure
- *
- *****************************************************************************/
-static int clear_multiboot_val(void)
-{
-	int ret = XST_FAILURE;
-
-	ret = system("echo 0xffca0010 0xfffffff 0x0 \
-	> /sys/firmware/zynqmp/config_reg");
-	if(ret)
-		return XST_FAILURE;
-
-	return XST_SUCCESS;
-}
-
 /*****************************************************************************/
 /**
  * @brief
